==> CloudClientStandardAWS_v2.0.0.zip: com.clustercontrol.cloud.base_2.0.0/com/clustercontrol/cloud/presenter/CreateCloudTemplateRequest.java <==
package com.clustercontrol.cloud.presenter;

import com.clustercontrol.cloud.commons.util.annotation.Export;
import com.clustercontrol.cloud.commons.util.annotation.Import;

public class CreateCloudTemplateRequest {
    protected String imageId;
    protected String launchJobId;
    protected String region;
    protected String startJobId;
    protected String stopJobId;
    protected String templateId;
    protected String templateName;
    
    @Export
	public String getImageId() {
		return imageId;
	}
    
    @Import
	public void setImageId(String imageId) {
		this.imageId = imageId;
	}
    
    @Export
	public String getLaunchJobId() {
		return launchJobId;
	}
    
    @Import
	public void setLaunchJobId(String launchJobId) {
		this.launchJobId = launchJobId;
	}
    
    @Export
	public String getRegion() {
		return region;
	}
    
    @Import
	public void setRegion(String region) {
		this.region = region;
	}
    
    @Export
	public String getStartJobId() {
		return startJobId;
	}
    
    @Import
	public void setStartJobId(String startJobId) {
		this.startJobId = startJobId;
	}
    
    @Export
	public String getStopJobId() {
		return stopJobId;
	}
    
    @Import
	public void setStopJobId(String stopJobId) {
		this.stopJobId = stopJobId;
	}
    
    @Export
	public String getTemplateId() {
		return templateId;
	}
    
    @Import
	public void setTemplateId(String templateId) {
		this.templateId = templateId;
	}
    
    @Export
	public String getTemplateName() {
		return templateName;
	}
    
    @Import
	public void setTemplateName(String templateName) {
		this.templateName = templateName;
	}
}

==> CloudClientStandardAWS_v2.0.4.zip: com.clustercontrol.cloud.base_2.0.4/com/clustercontrol/cloud/presenter/CreateCloudTemplateRequest.java <==
/*
Copyright (C) 2013 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.
 */
package com.clustercontrol.cloud.presenter;

import com.clustercontrol.cloud.commons.util.annotation.Export;
import com.clustercontrol.cloud.commons.util.annotation.Import;

public class CreateCloudTemplateRequest {
    protected String imageId;
    protected String launchJobId;
    protected String region;
    protected String startJobId;
    protected String stopJobId;
    protected String templateId;
    protected String templateName;
    
    @Export
	public String getImageId() {
		return imageId;
	}
    
    @Import
	public void setImageId(String imageId) {
		this.imageId = imageId;
	}
    
    @Export
	public String getLaunchJobId() {
		return launchJobId;
	}
    
    @Import
	public void setLaunchJobId(String launchJobId) {
		this.launchJobId = launchJobId;
	}
    
    @Export
	public String getRegion() {
		return region;
	}
    
    @Import
	public void setRegion(String region) {
		this.region = region;
	}
    
    @Export
	public String getStartJobId() {
		return startJobId;
	}
    
    @Import
	public void setStartJobId(String startJobId) {
		this.startJobId = startJobId;
	}
    
    @Export
	public String getStopJobId() {
		return stopJobId;
	}
    
    @Import
	public void setStopJobId(String stopJobId) {
		this.stopJobId = stopJobId;
	}
    
    @Export
	public String getTemplateId() {
		return templateId;
	}
    
    @Import
	public void setTemplateId(String templateId) {
		this.templateId = templateId;
	}
    
    @Export
	public String getTemplateName() {
		return templateName;
	}
    
    @Import
	public void setTemplateName(String templateName) {
		this.templateName = templateName;
	}
}
